@@ -1,4 +1,4 @@
-use crate::{context::StyleContext, styles::PointSize};
+use crate::{context::StyleContext, styles::*};
 
 mod context;
 mod styles;
